/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 0.1 as ListItem

Page {
    title: i18n.tr("High Scores")

    Flickable {
        anchors {
            fill: parent
        }
        height: parent.height
        contentHeight: scoresColumn.childrenRect.height

        Column {
            id: scoresColumn
            anchors {
                fill: parent
            }

            ListItem.Header {
                text: i18n.tr("First to") + " " + settings.targetScore
            }

            ListItem.SingleValue {
                objectName: "firstToXScore"
                text: settings.firstToXScore < 0 ? i18n.tr("N/A") : settings.firstToXScore + " " + i18n.tr("seconds")
            }

            ListItem.Header {
                text: i18n.tr("Highest Score")
            }

            ListItem.SingleValue {
                objectName: "highestScore"
                text: settings.highestScore < 0 ? i18n.tr("N/A") : settings.highestScore + " " + i18n.tr("points") || i18n.tr("N/A")
            }

            ListItem.Header {
                text: i18n.tr("Survival")
            }

            ListItem.SingleValue {
                objectName: "survivalScore"
                text: settings.survivalScore < 0 ? i18n.tr("N/A") : settings.survivalScore + " " + i18n.tr("points") || i18n.tr("N/A")
            }

            ListItem.Empty {
                Button {
                    anchors {
                        centerIn: parent
                    }
                    text: i18n.tr("Reset")

                    onClicked: {  // TODO: add autopilot tests
                        settings.firstToXScore = -1
                        settings.highestScore = -1
                        settings.survivalScore = -1
                    }
                }
                showDivider: false
            }
        }
    }
}
