/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 0.1 as ListItem

Page {
    id: settingsPage
    title: i18n.tr("Settings")

    Flickable {
        anchors {
            fill: parent
        }
        height: parent.height
        contentHeight: settingsColumn.childrenRect.height
        objectName: "settingsFlickable"

        Column {
            id: settingsColumn
            anchors {
                fill: parent
            }

            ListItem.Header {
                text: i18n.tr("Controls")
            }

            ListItem.Standard {
                control: CheckBox {
                    checked: settings.useMotion
                    objectName: "motionCheckBox"
                    onClicked: settings.useMotion = !settings.useMotion
                }
                text: i18n.tr("Use motion")
            }

            ListItem.Standard {
                control: Slider {
                    live: true
                    minimumValue: 0
                    maximumValue: 5
                    objectName: "motionDeadZoneSlider"
                    value: settings.motionDeadZone
                    width: settingsPage.width / 3
                    onValueChanged: settings.motionDeadZone = value
                }
                enabled: settings.useMotion
                objectName: "motionDeadZoneListItem"
                text: i18n.tr("Motion deadzone")
            }

            ListItem.Standard {
                control: Slider {
                    live: true
                    function formatValue(v) { return v.toFixed(2) }
                    minimumValue: 0.5
                    maximumValue: 1.0
                    objectName: "motionSensitivitySlider"
                    value: settings.motionSensitivity
                    width: settingsPage.width / 3
                    onValueChanged: settings.motionSensitivity = value
                }
                enabled: settings.useMotion
                objectName: "motionSensitivityListItem"
                text: i18n.tr("Motion sensitivity")
            }

            ListItem.Header {
                text: i18n.tr("Game")
            }

            ListItem.Standard {
                control: CheckBox {
                    checked: settings.fullscreen
                    objectName: "fullscreenCheckBox"
                    onClicked: settings.fullscreen = !settings.fullscreen
                }
                text: i18n.tr("Fullscreen")
            }

            ListItem.Header {
                text: i18n.tr("Debug")
            }

            ListItem.Standard {
                text: i18n.tr("AI Debug Layer")
                control: CheckBox {
                    checked: settings.aiDebugLayer
                    objectName: "aiDebugCheckBox"
                    onClicked: settings.aiDebugLayer = !settings.aiDebugLayer
                }
            }

            ListItem.Empty {
                Button {
                    anchors {
                        centerIn: parent
                    }
                    text: i18n.tr("Reset")

                    onClicked: {  // TODO: add autopilot tests
                        settings.useMotion = true
                        settings.motionDeadZone = 3
                        settings.motionSensitivity = 0.75
                        settings.fullscreen = true
                        settings.aiDebugLayer = false

                        mainPageStack.pop()  // return back to the menu
                    }
                }
                showDivider: false
            }
        }
    }
}
